A library for discovering content using the mainline DHT.
This library contains the protocol for announcing and querying content, as well as the client side implementation and a few helpers for p2p quinn connections.
Modules
- protocol
- The protocol for communicating with the tracker.
- tls_
utils - TLS configuration based on libp2p TLS specs.
Structs
Enums
- Connection
- Tracker
Id - A tracker id for queries - either a node id or an address.
Traits
- Quinn
Connection Provider - A connection provider that can be used to connect to a tracker.
Functions
- announce_
dht - Announce to the mainline DHT in parallel.
- announce_
iroh - Announce to a tracker.
- announce_
quinn - Announce to a tracker.
- connect
- Connect to a tracker using the crate::protocol::ALPN protocol, using either a node id or an address.
- create_
quinn_ client - Create a quinn client endpoint.
- query_
dht - Query the mainline DHT for trackers for the given content, then query each tracker for peers.
- query_
iroh - Assume an existing connection to a tracker and query it for peers for some content.
- query_
quinn - Assume an existing connection to a tracker and query it for peers for some content.
- query_
trackers - Query multiple trackers in parallel and merge the results.
- to_
infohash - The mapping from an iroh HashAndFormat to a bittorrent infohash, aka mainline::Id.